@@ -1,21 +1,13 @@
 import os
 import shutil
-import time
-from collections import Counter
-
-
-import cv2
 import numpy as np
-
-import matplotlib.pyplot as plt
 import torch
 
 from Graph import Grapher
-from Data_for_gcn import load_train_test_split, load_predictionData
+from Data_for_gcn import load_predictionData
 from torch_geometric.utils.convert import from_networkx
 
 
-
 def clearOutputFolder(test_output_fd):
     shutil.rmtree(test_output_fd)
     if not os.path.exists(test_output_fd):
